@@ -2,13 +2,13 @@ use strict;
 use warnings;
 package AnyEvent::OWNet;
 BEGIN {
-  $AnyEvent::OWNet::VERSION = '1.110180';
+  $AnyEvent::OWNet::VERSION = '1.110430';
 }
 
 # ABSTRACT: Client for 1-wire File System server
 
 
-use 5.010;
+use 5.008;
 use constant DEBUG => $ENV{ANYEVENT_OWNET_DEBUG};
 use AnyEvent;
 use AnyEvent::Handle;
@@ -35,13 +35,14 @@ sub new {
 
 sub _msg {
   my ($self, $req) = @_;
-  my $version = $req->{version} // 0;
-  my $data = $req->{data} // '';
+  my $version = exists $req->{version} ? $req->{version} : 0;
+  my $data = exists $req->{data} ? $req->{data} : '';
   my $payload = length $data;
-  my $type = $req->{type} // OWNET_MSG_READ; # default to read
-  my $sg = $req->{sg} // OWNET_DEFAULT_FLAGS;
-  my $size = $req->{size} // OWNET_DEFAULT_DATA_SIZE;
-  my $offset = $req->{offset} // 0;
+  my $type =
+    exists $req->{type} ? $req->{type} : OWNET_MSG_READ; # default to read
+  my $sg = exists $req->{sg} ? $req->{sg} : OWNET_DEFAULT_FLAGS;
+  my $size = exists $req->{size} ? $req->{size} : OWNET_DEFAULT_DATA_SIZE;
+  my $offset = exists $req->{offset} ? $req->{offset} : 0;
   return pack 'N6a*', $version, $payload, $type, $sg, $size, $offset, $data;
 }
 
@@ -347,7 +348,7 @@ AnyEvent::OWNet - Client for 1-wire File System server
 
 =head1 VERSION
 
-version 1.110180
+version 1.110430
 
 =head1 SYNOPSIS
 
